'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var path = _interopDefault(require('path'));
var readPkg = _interopDefault(require('read-pkg'));
var writePkg = _interopDefault(require('write-pkg'));

function readPackageJson(filePath) {
  try {
    return readPkg.sync(filePath, {
      normalize: false
    });
  } catch (e) {
    throw new Error('Input package.json file does not exist or has bad format, check "inputPackageJson" option');
  }
}

function writePackageJson(folder, contents) {
  try {
    return writePkg.sync(folder, contents);
  } catch (e) {
    throw new Error('Unable to save generated package.json file, check "outputFolder" option');
  }
}

function index (options = {}) {
  const inputPackageJson = readPackageJson(options.inputPackageJson);
  const baseContents = options.baseContents || {};
  const additionalDependencies = options.additionalDependencies || [];
  let dependencies = [];
  return {
    name: 'generate-package-json',
    ongenerate: ({
      bundle
    }) => {
      dependencies = [...bundle.imports, ...additionalDependencies].sort();
    },
    onwrite: details => {
      const outputPackageJson = options.outputFolder || path.dirname(details.file);
      const inputPackageJsonDependencies = inputPackageJson.dependencies;
      const generatedDependencies = {};
      dependencies.forEach(dependency => {
        if (inputPackageJsonDependencies && inputPackageJsonDependencies[dependency]) {
          generatedDependencies[dependency] = inputPackageJsonDependencies[dependency];
        }
      });
      const generatedJson = Object.assign({}, baseContents, Object.keys(generatedDependencies).length && {
        dependencies: generatedDependencies
      });
      writePackageJson(outputPackageJson, generatedJson);
    }
  };
}

module.exports = index;
